// src/modules/https-utils.ts
import { request } from "https";
function isStatusOK(result) {
  return result.statusCode !== void 0 && result.statusCode >= 200 && result.statusCode <= 399;
}
function requestWorks(url, method) {
  return new Promise((resolve) => {
    try {
      const req = request(url, { method }, (result) => {
        resolve(isStatusOK(result));
      });
      req.on("error", (_error) => {
        resolve(false);
      });
      req.end();
    } catch {
      resolve(false);
    }
  });
}

// src/modules/isUrlString.ts
import { URL } from "url";
var isUrlString = (url) => {
  if (typeof url !== "string") {
    return false;
  }
  const trimmedUrl = url.trim();
  if (trimmedUrl.includes(" ")) {
    return false;
  }
  try {
    new URL(trimmedUrl);
    return true;
  } catch {
    return false;
  }
};

// src/modules/isUrlOnline.ts
var isUrlOnline = async (url) => {
  const isUrl = isUrlString(url);
  if (!isUrl) {
    return false;
  }
  let response = await requestWorks(url, "HEAD");
  if (response) {
    return true;
  }
  response = await requestWorks(url, "GET");
  return !!response;
};

// src/modules/prependHttp.ts
var prependHttp = ({
  url,
  https = true
}) => {
  const trimmedUrl = url.trim();
  if (/^\.*\/|^(?!localhost)\w+:/u.test(trimmedUrl)) {
    return url;
  }
  return trimmedUrl.replace(
    /^(?!(?:\w+:)?\/\/)/u,
    https ? "https://" : "http://"
  );
};
export {
  isUrlOnline,
  isUrlString,
  prependHttp
};
